<#
Written by: Stephen W Thomas
Email: me@biztalkguru.com
Twitter: @stephenwthomas
Community Site: www.BIzTalkGurus.com
Personal Site: www.BizTalkGuru.com

Content provided as-is.  Use at your own risk.  Charges may/will apply when creating VMs inside Windows Azure. 

This script will create a new VM using the Windows 2012 Image from the variables file.
It will install ADDS and create a new domain.
It also creates all the BizTalk users and adds the Domain Admin as a BizTalk and SSO Admin.

Change Log:
1.0 (6/2/2014) - Initial release (Tested with May 2014 PowerShell Commands - older versions may not work)
#>

"Start - creating the PDC"
Set-AzureSubscription -SubscriptionName $subscriptionName -CurrentStorageAccount $defaultStorageAccount -ErrorAction SilentlyContinue
Select-AzureSubscription -SubscriptionName $subscriptionName

# User Loopback
$myDNS = New-AzureDNS -Name $dnsName -IPAddress $dnsLoopBackIP

$strPassword = ConvertTo-SecureString $password -AsPlainText -Force
$credential = New-Object System.Management.Automation.PSCredential ($domainAdminUserName, $strPassword)

#VM Configuration
$MyDC = New-AzureVMConfig -name $vmnamePDC -InstanceSize $sizePDC -ImageName $imageWindows | `
        Add-AzureProvisioningConfig -Windows -AdminUsername $domainAdminUserName -Password $password | `
        Set-AzureSubnet -SubnetNames $subNetName | `
        Set-AzureStaticVNetIP -IPAddress $dnsIP
        
New-AzureVM -ServiceName $vmnamePDC -AffinityGroup $affinityGroup -VMs $MyDC -DnsSettings $myDNS -VNetName $virtualNetwork -WaitForBoot -ErrorAction Stop

"End - creating the PDC"
 
# Get the RemotePS/WinRM Uri to connect to
$uri = Get-AzureWinRMUri -ServiceName $vmnamePDC -Name $vmnamePDC
 
# Using generated certs  use helper function to download and install generated cert.
InstallWinRMCert $vmnamePDC $vmnamePDC
 
"Start - AD Install"
Invoke-Command -ConnectionUri $uri.ToString() -Credential $credential -ScriptBlock {
    param($domainName, $password)
    $strPassword = ConvertTo-SecureString $password -AsPlainText -Force
    Install-windowsfeature -name AD-Domain-Services IncludeManagementTools
    Install-ADDSForest -SkipPreChecks DomainName $domainName -SafeModeAdministratorPassword $strPassword -Force 
} -ArgumentList $domainName, $password
"End - AD Install"

# Wait for the services to start
Start-Sleep -s 240

"Start - User / Domain Group setup"
Invoke-Command -ConnectionUri $uri.ToString() -Credential $credential -ScriptBlock {
    param($password, $domainAdminUserName)
    $strPassword = ConvertTo-SecureString $password -AsPlainText -Force

    # Wait for ADWS to start just in case
    # Sometimes this gives a thread error
    while ((get-service -Name 'ADWS').Status -ne "Running") {
        "Waiting for ADWS to start ..."
        Start-Sleep -s 15
    }
    
    # These domain groups are hard coded inside the Multi Server Configuration file
    # Changes here will break the auto config process
    New-ADGroup -Name "SSO Administrators" -GroupCategory Security -GroupScope Global -DisplayName "SSO Administrators"
    New-ADGroup -Name "SSO Affiliate Administrators" -GroupCategory Security -GroupScope Global -DisplayName "SSO Affiliate Administrators"
    New-ADGroup -Name "BizTalk Application Users" -GroupCategory Security -GroupScope Global -DisplayName "BizTalk Application Users"
    New-ADGroup -Name "BizTalk Isolated Host Users" -GroupCategory Security -GroupScope Global -DisplayName "BizTalk Isolated Host Users"
    New-ADGroup -Name "BizTalk Server Administrators" -GroupCategory Security -GroupScope Global -DisplayName "BizTalk Server Administrators"
    New-ADGroup -Name "BizTalk Server Operators" -GroupCategory Security -GroupScope Global -DisplayName "BizTalk Server Operators"
    New-ADGroup -Name "BizTalk Server B2B Operators" -GroupCategory Security -GroupScope Global -DisplayName "BizTalk Server B2B Operators"
    New-ADUser -SamAccountName SSOService -AccountPassword $strPassword -name "SSOService" -enabled $true -PasswordNeverExpires $true -CannotChangePassword $true  -ChangePasswordAtLogon $false
    New-ADUser -SamAccountName BTSAppHost -AccountPassword $strPassword -name "BTSAppHost" -enabled $true -PasswordNeverExpires $true -CannotChangePassword $true  -ChangePasswordAtLogon $false
    New-ADUser -SamAccountName BTSIsolatedHost -AccountPassword $strPassword -name "BTSIsolatedHost" -enabled $true -PasswordNeverExpires $true -CannotChangePassword $true  -ChangePasswordAtLogon $false
    New-ADUser -SamAccountName BTSAdmin -AccountPassword $strPassword -name "BTSAdmin" -enabled $true -PasswordNeverExpires $true -CannotChangePassword $true  -ChangePasswordAtLogon $false
    Add-ADPrincipalGroupMembership -Identity "SSOService" -MemberOf "SSO Administrators"
    Add-ADPrincipalGroupMembership -Identity "BizTalk Server Administrators" -MemberOf "SSO Administrators"
    Add-ADPrincipalGroupMembership -Identity "BTSAdmin" -MemberOf "BizTalk Server Administrators"
    Add-ADPrincipalGroupMembership -Identity "BTSAppHost" -MemberOf "BizTalk Application Users"
    Add-ADPrincipalGroupMembership -Identity "BTSIsolatedHost" -MemberOf "BizTalk Isolated Host Users"
    Add-ADPrincipalGroupMembership -Identity $domainAdminUserName -MemberOf "BizTalk Server Administrators"
    Add-ADPrincipalGroupMembership -Identity $domainAdminUserName -MemberOf "SSO Administrators"
    Add-ADPrincipalGroupMembership -Identity $domainAdminUserName -MemberOf "BizTalk Isolated Host Users"
    Add-ADPrincipalGroupMembership -Identity $domainAdminUserName -MemberOf "BizTalk Application Users"
} -ArgumentList $password, $domainAdminUserName
"End - User / Domain Group setup"